==> jc-1.4.0.tar.gz: java/lang/reflect/AccessibleObject.h <==
// public class java.lang.reflect.AccessibleObject

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2272439d2affe42f java_lang_reflect_AccessibleObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_AccessibleObject_H_
#define _JC_java_lang_reflect_AccessibleObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_reflect_AccessibleObject$sub_refs	_jc_java_lang_reflect_AccessibleObject$sub_refs;
typedef struct _jc_java_lang_reflect_AccessibleObject$sub_nonrefs	_jc_java_lang_reflect_AccessibleObject$sub_nonrefs;
typedef struct _jc_java_lang_reflect_AccessibleObject$refs	_jc_java_lang_reflect_AccessibleObject$refs;
typedef struct _jc_java_lang_reflect_AccessibleObject$nonrefs	_jc_java_lang_reflect_AccessibleObject$nonrefs;
typedef struct _jc_java_lang_reflect_AccessibleObject$object	_jc_java_lang_reflect_AccessibleObject$object;

typedef struct _jc_java_lang_reflect_AccessibleObject$fields_struct	_jc_java_lang_reflect_AccessibleObject$fields_struct;
typedef const struct _jc_java_lang_reflect_AccessibleObject$vmethods	_jc_java_lang_reflect_AccessibleObject$vmethods;
typedef const struct _jc_java_lang_reflect_AccessibleObject$vtable	_jc_java_lang_reflect_AccessibleObject$vtable;
typedef const struct _jc_java_lang_reflect_AccessibleObject$vtype	_jc_java_lang_reflect_AccessibleObject$vtype;

// Class fields structure
struct _jc_java_lang_reflect_AccessibleObject$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Class;
};
extern _jc_java_lang_reflect_AccessibleObject$fields_struct _jc_java_lang_reflect_AccessibleObject$class_fields;

// Constructors
extern void _jc_java_lang_reflect_AccessibleObject$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *);

// Virtual methods
extern jboolean _jc_java_lang_reflect_AccessibleObject$method$isAccessible$057e7499cc917366(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *);
extern void _jc_java_lang_reflect_AccessibleObject$method$secureSetAccessible$4c760fdd9c1f3fed(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *, jboolean);
extern void _jc_java_lang_reflect_AccessibleObject$method$setAccessible$89d4aa6d2514a574(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *, jboolean);
extern void _jc_java_lang_reflect_AccessibleObject$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_AccessibleObject$method_info$isAccessible$057e7499cc917366;
extern _jc_method _jc_java_lang_reflect_AccessibleObject$method_info$secureSetAccessible$4c760fdd9c1f3fed;
extern _jc_method _jc_java_lang_reflect_AccessibleObject$method_info$setAccessible$89d4aa6d2514a574;
extern _jc_method _jc_java_lang_reflect_AccessibleObject$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_lang_reflect_AccessibleObject$method$checkPermission$9c717d366c4fbd3a(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_AccessibleObject$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_java_lang_reflect_AccessibleObject$method$setAccessible$6a80f62ca1bb27c3(_jc_env *, struct _jc_object_array *, jboolean);

// Virtual methods structure
struct _jc_java_lang_reflect_AccessibleObject$vmethods {
	jboolean	(*isAccessible$057e7499cc917366)(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *);
	void	(*secureSetAccessible$4c760fdd9c1f3fed)(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *, jboolean);
	void	(*setAccessible$89d4aa6d2514a574)(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *, jboolean);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *);
};

// Vtable
struct _jc_java_lang_reflect_AccessibleObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_AccessibleObject$vmethods	java_lang_reflect_AccessibleObject;
};

// Vtype
struct _jc_java_lang_reflect_AccessibleObject$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_AccessibleObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_AccessibleObject$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_AccessibleObject$refs {
    _jc_java_lang_reflect_AccessibleObject$sub_refs	java_lang_reflect_AccessibleObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_AccessibleObject$sub_nonrefs {
	jboolean	flag;
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_AccessibleObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_AccessibleObject$sub_nonrefs	java_lang_reflect_AccessibleObject;
};

// Object instance structure
struct _jc_java_lang_reflect_AccessibleObject$object {
	_jc_java_lang_reflect_AccessibleObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_AccessibleObject$vtype	*vtype;
	_jc_java_lang_reflect_AccessibleObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_AccessibleObject$vtype _jc_java_lang_reflect_AccessibleObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_AccessibleObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_AccessibleObject$class_object;

#endif	/* _JC_java_lang_reflect_AccessibleObject_H_ */

==> jc-1.4.6.tar.gz: java/lang/reflect/AccessibleObject.h <==
// public class java.lang.reflect.AccessibleObject

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2272439d2affe42f java_lang_reflect_AccessibleObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_AccessibleObject_H_
#define _JC_java_lang_reflect_AccessibleObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_reflect_AccessibleObject$sub_refs	_jc_java_lang_reflect_AccessibleObject$sub_refs;
typedef struct _jc_java_lang_reflect_AccessibleObject$sub_nonrefs	_jc_java_lang_reflect_AccessibleObject$sub_nonrefs;
typedef struct _jc_java_lang_reflect_AccessibleObject$refs	_jc_java_lang_reflect_AccessibleObject$refs;
typedef struct _jc_java_lang_reflect_AccessibleObject$nonrefs	_jc_java_lang_reflect_AccessibleObject$nonrefs;
typedef struct _jc_java_lang_reflect_AccessibleObject$object	_jc_java_lang_reflect_AccessibleObject$object;

typedef struct _jc_java_lang_reflect_AccessibleObject$fields_struct	_jc_java_lang_reflect_AccessibleObject$fields_struct;
typedef const struct _jc_java_lang_reflect_AccessibleObject$vmethods	_jc_java_lang_reflect_AccessibleObject$vmethods;
typedef const struct _jc_java_lang_reflect_AccessibleObject$vtable	_jc_java_lang_reflect_AccessibleObject$vtable;
typedef const struct _jc_java_lang_reflect_AccessibleObject$vtype	_jc_java_lang_reflect_AccessibleObject$vtype;

// Class fields structure
struct _jc_java_lang_reflect_AccessibleObject$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Class;
};
extern _jc_java_lang_reflect_AccessibleObject$fields_struct _jc_java_lang_reflect_AccessibleObject$class_fields;

// Constructors
extern void _jc_java_lang_reflect_AccessibleObject$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_lang_reflect_AccessibleObject$method$isAccessible$057e7499cc917366(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_reflect_AccessibleObject$method$secureSetAccessible$4c760fdd9c1f3fed(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_lang_reflect_AccessibleObject$method$setAccessible$89d4aa6d2514a574(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_lang_reflect_AccessibleObject$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_AccessibleObject$method_info$isAccessible$057e7499cc917366;
extern _jc_method _jc_java_lang_reflect_AccessibleObject$method_info$secureSetAccessible$4c760fdd9c1f3fed;
extern _jc_method _jc_java_lang_reflect_AccessibleObject$method_info$setAccessible$89d4aa6d2514a574;
extern _jc_method _jc_java_lang_reflect_AccessibleObject$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_lang_reflect_AccessibleObject$method$checkPermission$9c717d366c4fbd3a(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_AccessibleObject$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_lang_reflect_AccessibleObject$method$setAccessible$6a80f62ca1bb27c3(_jc_env *, struct _jc_object_array *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_reflect_AccessibleObject$vmethods {
	jboolean	(*isAccessible$057e7499cc917366)(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *) _JC_JCNI_ATTR;
	void	(*secureSetAccessible$4c760fdd9c1f3fed)(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *, jboolean) _JC_JCNI_ATTR;
	void	(*setAccessible$89d4aa6d2514a574)(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *, jboolean) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_lang_reflect_AccessibleObject$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_reflect_AccessibleObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_AccessibleObject$vmethods	java_lang_reflect_AccessibleObject;
};

// Vtype
struct _jc_java_lang_reflect_AccessibleObject$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_AccessibleObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_AccessibleObject$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_AccessibleObject$refs {
    _jc_java_lang_reflect_AccessibleObject$sub_refs	java_lang_reflect_AccessibleObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_AccessibleObject$sub_nonrefs {
	jboolean	flag;
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_AccessibleObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_AccessibleObject$sub_nonrefs	java_lang_reflect_AccessibleObject;
};

// Object instance structure
struct _jc_java_lang_reflect_AccessibleObject$object {
	_jc_java_lang_reflect_AccessibleObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_AccessibleObject$vtype	*vtype;
	_jc_java_lang_reflect_AccessibleObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_AccessibleObject$vtype _jc_java_lang_reflect_AccessibleObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_AccessibleObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_AccessibleObject$class_object;

#endif	/* _JC_java_lang_reflect_AccessibleObject_H_ */
